function SingleCompartmentModel2

%% clear screen
clc

%% global variables
global data;
global datas;
global Parameter; 

%% load experimental data
PREdata= load('CHO.txt'); %without SORLA
PREdatas= load('CHO_S.txt'); %with SORLA 

%% Choices
%   12: local estimation of parameter values -  affect Kma of both monomer and dimer
%   13: local estimation of parameter values -  affect Kmb of both monomer and dimer
%   14: global estimation of parameter values
choice=13;

%% open file to record parameter values that will be estimated
if (choice==12)
fid = fopen('SingleCompartmentBoth_localKma.txt',  'at');
elseif (choice==13)
fid = fopen('SingleCompartmentBoth_localKmb.txt',  'at');
elseif (choice==14)
fid = fopen('SingleCompartmentBoth_global.txt',  'at');
end
 
%% sort experimental data according to the total amount of APP measured in the experiments
data = sortrows(PREdata, 1); %without SORLA
datas = sortrows(PREdatas, 1); %with SORLA

%% data sets 
%without SORLA
xdata = data(:, 1).* 50; %convert total APP from nM into fmol
ydataA = data(:, 2);%sAPPa
ydataB = data(:, 3); %sAPPb
% with SORLA
xdatas = datas(:, 1) .* 50; %convert total APP from nM into fmol
ydataAs = datas(:, 2);%sAPPa
ydataBs = datas(:, 3); %sAPPb
% back up vectors of the experimental data
xdata8=xdata;
ydataA8=ydataA;
ydataB8=ydataB;
xdata8s=xdatas;
ydataA8s=ydataAs;
ydataB8s=ydataBs;
% a copy of vector APP in nM for plotting purpose
xdata8P= data(:, 1);
xdata8sP= datas(:, 1);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% initial loop
loop=1;
%% row denotes the number of repetitions
for row=1:500
    tempflag=row 
%% initial parameter values
% for dimer processing
k6d=100* rand(1); 
Kmad=100* rand(1);       
k4d=100* rand(1);     
Kmbd=100* rand(1);           
% for monomer processing
k6=100* rand(1);      
Kma=100* rand(1);       
k4=100* rand(1); 
Kmb=100* rand(1);           
% shared by both processing
Atot=100* rand(1); %total amount of alpha-secretase
Btot=100.* rand(1); %total amount of beta-secretase
Ka=100* rand(1);   %constant ratio for APP dimerization
Kb=100* rand(1);    %constant ratio for beta dimerization
Kc=100* rand(1);    %constant ratio for alpha dimerization
sor=100* rand(1); %SORLA 
Ksor=100* rand(1);%dissociation constant of SORLA and APP 
tune=100* rand(1);%variable that may varies for local estimation of Km values
tune2=100* rand(1);%variable that may varies for local estimation of Km values
 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%% call the nonlinear least square function lsqnonlin()  
options = optimset('PrecondBandWidth', 0);
if (choice==12 || choice==13)
[Parameter,  resi] = lsqnonlin(@mycurve, [Atot, Btot, k6d,  Kmad,  k4d,  Kmbd, k6, Kma, k4, Kmb, Ka,  Kb,  Kc, sor, Ksor, tune, tune2], [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0], [], options);
elseif (choice==14)
[Parameter,  resi] = lsqnonlin(@mycurve, [Atot,  Btot,  k6d,  Kmad,  k4d,  Kmbd, k6, Kma, k4, Kmb, Ka,  Kb,  Kc, sor, Ksor], [0 0 0 0 0 0 0 0 0 0 0 0 0 0 0], [], options);
end
%with SORLA (temporarily assignment)
Parameter(101)=Parameter(1);%Atot
Parameter(102)=Parameter(2);%Btot
Parameter(103)=Parameter(3);%k6d
Parameter(105)=Parameter(5);%k4d
Parameter(107)=Parameter(7);%k6
Parameter(109)=Parameter(9);%k4 
Parameter(111)=Parameter(11);%Ka
Parameter(112)=Parameter(12);%Kb
Parameter(113)=Parameter(13);%Kc
if (choice==12)
Parameter(104)=Parameter(16);%Kma dimer
Parameter(106)=Parameter(6);%Kmb dimer
Parameter(108)=Parameter(17);%Kma monomer
Parameter(110)=Parameter(10);%Kmb monomer
elseif (choice==13)
Parameter(104)=Parameter(4);%Kma dimer
Parameter(106)=Parameter(16);%Kmb dimer
Parameter(108)=Parameter(8);%Kma monomer
Parameter(110)=Parameter(17);%Kmb monomer
elseif (choice==14)
Parameter(104)=Parameter(4);%Kma dimer
Parameter(106)=Parameter(6);%Kmb dimer
Parameter(108)=Parameter(8);%Kma monomer
Parameter(110)=Parameter(10);%Kmb monomer
end
Ka=Parameter(11);
Kb=Parameter(12);
Kc=Parameter(13);
s=Parameter(14);
Ks=Parameter(15);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% to check if there is negative parameter estimated 
if (s>0 && Ks>0 && Parameter(101)>0 && Parameter(102)>0 && Parameter(103)>0 && Parameter(104)>0 && Parameter(105)>0 && Parameter(106)>0 && Parameter(107)>0 && Parameter(108)>0 && Parameter(109)>0 && Parameter(110)>0 && Parameter(111)>0 && Parameter(112)>0 && Parameter(113)>0)
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% Mathematical representation
% See Equations~\ref{MonoDimerAPPtot}~and~\ref{MonoDimerConservedEqn2} for monomer and dimer processing, respectively

appF= appFSOLVE';
appFs= appFSOLVEs'; 
datum= xdata8(:, 1); 
datums= xdata8s(:, 1);

%without SORLA
alpha=(- appF.* Parameter(4) -  Parameter(8).* Parameter(4) +  sqrt((- appF.* Parameter(4) -  Parameter(8).* Parameter(4)).^2 -  4.*  Parameter(1).*  Parameter(8).*  Parameter(4).*  (- 2.*  appF.^2.*  Ka.*  Kc.*  Parameter(8) -  2.*  Kc.*  Parameter(8).*  Parameter(4))))./ (4.*  (appF.^2 .* Ka.*  Kc.*  Parameter(8) +  Kc.*  Parameter(8).*  Parameter(4)));
beta =(- appF.* Parameter(6) -  Parameter(10).* Parameter(6) +  sqrt((- appF.* Parameter(6) -  Parameter(10).* Parameter(6)).^2 -  4.*  Parameter(2).*  Parameter(10).*  Parameter(6).*  (- 2.*  appF.^2.*  Ka.*  Kb.*  Parameter(10) -  2.*  Kb.*  Parameter(10).*  Parameter(6))))./ (4.*  (appF.^2 .* Ka.*  Kb.*  Parameter(10) +  Kb.*  Parameter(10).*  Parameter(6)));
appTOT=appF.* (1+  alpha./ Parameter(8)+  beta./ Parameter(10)) + (2.* Ka.* appF.^2).* (1 +  Kc.* (alpha.^2)./ Parameter(4) +  Kb.* (beta.^2)./ Parameter(6));

%with SORLA
alphas=(- appFs.* Parameter(104) -  Parameter(108).* Parameter(104) +  sqrt((- appFs.* Parameter(104) -  Parameter(108).* Parameter(104)).^2 -  4.*  Parameter(101).*  Parameter(108).*  Parameter(104).*  (- 2.*  appFs.^2.*  Ka.*  Kc.*  Parameter(108) -  2.*  Kc.*  Parameter(108).*  Parameter(104))))./ (4.*  (appFs.^2 .* Ka.*  Kc.*  Parameter(108) +  Kc.*  Parameter(108).*  Parameter(104)));
betas =(- appFs.* Parameter(106) -  Parameter(110).* Parameter(106) +  sqrt((- appFs.* Parameter(106) -  Parameter(110).* Parameter(106)).^2 -  4.*  Parameter(102).*  Parameter(110).*  Parameter(106).*  (- 2.*  appFs.^2.*  Ka.*  Kb.*  Parameter(110) -  2.*  Kb.*  Parameter(110).*  Parameter(106))))./ (4.*  (appFs.^2 .* Ka.*  Kb.*  Parameter(110) +  Kb.*  Parameter(110).*  Parameter(106)));
appTOTs=appFs.* (1+ s./ (Ks+ appFs) + alphas./ Parameter(108) +  betas./ Parameter(110)) + (2.* Ka.* appFs.^2).* (1 +  Kc.* (alphas.^2)./ Parameter(104) +  Kb.* (betas.^2)./ Parameter(106));


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% check if the difference between the given appTOT and estimated appTOT 
% increment count if 
% (1) the Difference is larger than the threshold value
% (2) free APPs is negative
 
Diff=abs(appTOT- datum);
Diffs=abs(appTOTs- datums);

u=length(appF);
us=length(appFs);
threshold = 0.00000001;
count=0;
count2=0;
for t=1:u
   if ( Diff(t) > threshold)
        count = count + 1;
   end
   if (appF(t) < 0)
         count2 = count2 +  1;
   end  
end
for ts=1:us
   if ( Diffs(ts) > threshold)
        count = count + 1;
   end
   if (appFs(ts) < 0)
         count2 = count2 +  1;
   end  
end
% checkpoint: restart if count or count2 <0
if ((count >0) || (count2 >0))
    continue; 
else

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plotting: plot the original data (CHO.txt and CHO_S.txt) together with simulation results of the model
% See Equations~\ref{MonoDimerEndProducts}~and~\ref{EndProducts2}

appTOT=appTOT./ 50; %convert back from fmol to nM for plotting     
appTOTs=appTOTs./ 50; %convert back from fmol to nM for plotting
appTOT=vertcat(0, appTOT);
appTOTs=vertcat(0, appTOTs);
appFree=vertcat(0, appF);
appFrees=vertcat(0, appFs);
alpha=vertcat(0, alpha);
beta=vertcat(0, beta);
alphas=vertcat(0, alphas);
betas=vertcat(0, betas);
appM=appFree;
appD=Ka.* (appFree.^2);
appMs=appFrees;
appDs=Ka.* (appFrees.^2);


% without SORLA
figure(3000+ loop)
plot(xdata8P, ydataA8, 'k.', 'MarkerSize', 10)
hold on 
fitteda1 = 2.* (appD).* (Kc.* (alpha.^2)).*  Parameter(3)./ Parameter(4); %dimer
fitteda2 = (appM).* alpha.*  Parameter(7)./ Parameter(8); %monomer
fitteda1P = fitteda1;
fitteda2P = fitteda2;
fitted = fitteda1P+  fitteda2P;
plot(appTOT, fitteda1P, 'g- ', 'LineWidth', 2)%dimer
plot(appTOT, fitteda2P, 'm- ', 'LineWidth', 2)%monomer
plot(appTOT, fitted, 'k- ', 'LineWidth', 2)
xlabel('APP_{Tot}(nM)'); 
ylabel('sAPP_\backslashalpha(fmol/ h)')
xlim([0 400])
ylim([0 250])
 
figure(4000+ loop)
plot(xdata8P, ydataB8, 'k.', 'MarkerSize', 10)
hold on
fitted11 = 2.* (appD).* (Kb.* (beta.^2)).*  Parameter(5)./ Parameter(6); %dimer
fitted12 = (appM).* beta.*  Parameter(9)./ Parameter(10); %monomer
fitted11P = fitted11;
fitted12P = fitted12;
fitted1=fitted11P+ fitted12P;
plot(appTOT, fitted11P, 'g- ', 'LineWidth', 2)%dimer
plot(appTOT, fitted12P, 'm- ', 'LineWidth', 2)%monomer
plot(appTOT, fitted1, 'k- ', 'LineWidth', 2)
xlabel('APP_{Tot}(nM)'); 
ylabel('sAPP_\backslashbeta(fmol/ h)')
xlim([0 400])
ylim([0 12])
 
% with SORLA
figure(6000+ loop)
plot(xdata8sP, ydataA8s, 'k.', 'MarkerSize', 10)
hold on 
fitteda1s = 2.* (appDs).* (Kc.* (alphas.^2)).*  Parameter(103)./ Parameter(104); %dimer
fitteda2s = (appMs).* alphas.*  Parameter(107)./ Parameter(108); %monomer
fitteda1Ps = fitteda1s;
fitteda2Ps = fitteda2s;
fitteds = fitteda1Ps+  fitteda2Ps;
plot(appTOTs, fitteda1Ps, 'g- ', 'LineWidth', 2)%dimer
plot(appTOTs, fitteda2Ps, 'm- ', 'LineWidth', 2)%monomer
plot(appTOTs, fitteds, 'k- ', 'LineWidth', 2)
xlabel('APP_{Tot}(nM)'); 
ylabel('sAPP_\backslashalpha(fmol/ h)')
xlim([0 400])
ylim([0 250])
 
figure(7000+ loop)
plot(xdata8sP, ydataB8s, 'k.', 'MarkerSize', 10)
hold on
fitted11s = 2.* (appDs).* (Kb.* (betas.^2)).*  Parameter(105)./ Parameter(106); %dimer
fitted12s = (appMs).* betas.*  Parameter(109)./ Parameter(110); %monomer
fitted11Ps = fitted11s;
fitted12Ps = fitted12s;
fitted1s=fitted11Ps+ fitted12Ps;
plot(appTOTs, fitted11Ps, 'g- ', 'LineWidth', 2)%dimer
plot(appTOTs, fitted12Ps, 'm- ', 'LineWidth', 2)%monomer
plot(appTOTs, fitted1s, 'k- ', 'LineWidth', 2)
xlabel('APP_{Tot}(nM)'); 
ylabel('sAPP_\backslashbeta(fmol/ h)')
xlim([0 400])
ylim([0 12])

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Record the estimated paramters into the text file
% (1 residue +  28 parameters = 29 variables)
fprintf(fid,  '%12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f %12.12f\backslashn',  resi,  Parameter(1), Parameter(2),  Parameter(3),  Parameter(4), Parameter(5),  Parameter(6),  Parameter(7), Parameter(8),  Parameter(9),  Parameter(10),  Parameter(11),  Parameter(12), Parameter(13), Parameter(101), Parameter(102),  Parameter(103),  Parameter(104), Parameter(105),  Parameter(106),  Parameter(107), Parameter(108),  Parameter(109),  Parameter(110),  Parameter(111),  Parameter(112), Parameter(113), s, Ks);

%%  increment to the next loop
loop=loop+ 1; 
end
end
end
fclose(fid);    


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Subroutince to calculate the sum of squared of error by Least Square Method
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function err = mycurve(p)
%% initial assumptions:
% Unless specified otherwise, p(i)=Parameter(i) where i={1,2,...,15}
Ka=p(11);
Kb=p(12);
Kc=p(13);
s=p(14);
Ks=p(15);

%under the influence of SORLA
if (choice==12)%affect Kma monomer and dimer
Kma=p(17);
Kmad=p(16);
Kmb=p(10);
Kmbd=p(6);
elseif (choice==13)%affect Kmb monomer and dimer
Kma=p(8);
Kmad=p(4);
Kmb=p(17);
Kmbd=p(16);
elseif (choice==14)%affect nothing
Kma=p(8);
Kmad=p(4);
Kmb=p(10);
Kmbd=p(6);
end
 
% Initialization of vectors for the computed amount of free APP in the presence and absence of SORLA
% without SORLA
P = xdata8(:, 1);
w=length(P);
appFSOLVE=zeros(1, w);
% with SORLA
Ps = xdata8s(:, 1);
ws=length(Ps);
appFSOLVEs=zeros(1, ws); 
 
%% SOLVE for free APP given the total amount of APP (without SORLA): see Equations~\ref{MonoDimerAPPtot}~and~\ref{MonoDimerConservedEqn2}
for j=1:w
func=@(appF)(appF.* (1+  ((- appF.* p(4) -  p(8).* p(4) +  sqrt((- appF.* p(4) -  p(8).* p(4)).^2 -  4.*  p(1).*  p(8).*  p(4).*  (- 2.*  appF.^2.*  Ka.*  Kc.*  p(8) -  2.*  Kc.*  p(8).*  p(4))))./ (4.*  (appF.^2 .* Ka.*  Kc.*  p(8) +  Kc.*  p(8).*  p(4))))./ p(8)+  ((- appF.* p(6) -  p(10).* p(6) +  sqrt((- appF.* p(6) -  p(10).* p(6)).^2 -  4.*   p(2).*  p(10).*  p(6).*  (- 2.*  appF.^2.*  Ka.*  Kb.*  p(10) -  2.*  Kb.*  p(10).*  p(6))))./ (4.*  (appF.^2 .* Ka.*  Kb.*  p(10) +  Kb.*  p(10).*  p(6))))./ p(10)) + (2.* Ka.* appF.^2).* (1 +  Kc.* (((- appF.* p(4) -  p(8).* p(4) +  sqrt((- appF.* p(4) -  p(8).* p(4)).^2 -  4.*  p(1).*  p(8).*  p(4).*  (- 2.*  appF.^2.*  Ka.*  Kc.*  p(8) -  2.*  Kc.*  p(8).*  p(4))))./ (4.*  (appF.^2 .* Ka.*  Kc.*  p(8) +  Kc.*  p(8).*  p(4)))).^2)./ p(4) +  Kb.* (((- appF.* p(6) -  p(10).* p(6) +  sqrt((- appF.* p(6) -  p(10).* p(6)).^2 -  4.*   p(2).*  p(10).*  p(6).*  (- 2.*  appF.^2.*  Ka.*  Kb.*  p(10) -  2.*  Kb.*  p(10).*  p(6))))./ (4.*  (appF.^2 .* Ka.*  Kb.*  p(10) +  Kb.*  p(10).*  p(6)))).^2)./ p(6)) -  xdata8(j, 1));
  appFSOLVE(1, j)=fzero(func, [0 P(j)], optimset('fzero'));
end

%% SOLVE for free APP given the total amount of APP (with SORLA): see Equations~\ref{MonoDimerAPPtot}~and~\ref{MonoDimerConservedEqn2}
 
for js=1:ws
funcs=@(appFs)(appFs.* (1+  ((- appFs.* Kmad -  Kma.* Kmad +  sqrt((- appFs.* Kmad -  Kma.* Kmad).^2 -  4.*  p(1).*  Kma.*  Kmad.*  (- 2.*  appFs.^2.*  Ka.*  Kc.*  Kma -  2.*  Kc.*  Kma.*  Kmad)))./ (4.*  (appFs.^2 .* Ka.*  Kc.*  Kma +  Kc.*  Kma.*  Kmad)))./ Kma+  ((- appFs.* Kmbd -  Kmb.* Kmbd +  sqrt((- appFs.* Kmbd -  Kmb.* Kmbd).^2 -  4.*   p(2).*  Kmb.*  Kmbd.*  (- 2.*  appFs.^2.*  Ka.*  Kb.*  Kmb -  2.*  Kb.*  Kmb.*  Kmbd)))./ (4.*  (appFs.^2 .* Ka.*  Kb.*  Kmb +  Kb.*  Kmb.*  Kmbd)))./ Kmb) + (2.* Ka.* appFs.^2).* (1 +  Kc.* (((- appFs.* Kmad -  Kma.* Kmad +  sqrt((- appFs.* Kmad -  Kma.* Kmad).^2 -  4.*  p(1).*  Kma.*  Kmad.*  (- 2.*  appFs.^2.*  Ka.*  Kc.*  Kma -  2.*  Kc.*  Kma.*  Kmad)))./ (4.*  (appFs.^2 .* Ka.*  Kc.*  Kma +  Kc.*  Kma.*  Kmad))).^2)./ Kmad +  Kb.* (((- appFs.* Kmbd -  Kmb.* Kmbd +  sqrt((- appFs.* Kmbd -  Kmb.* Kmbd).^2 -  4.*   p(2).*  Kmb.*  Kmbd.*  (- 2.*  appFs.^2.*  Ka.*  Kb.*  Kmb -  2.*  Kb.*  Kmb.*  Kmbd)))./ (4.*  (appFs.^2 .* Ka.*  Kb.*  Kmb +  Kb.*  Kmb.*  Kmbd))).^2)./ Kmbd) +  appFs.* s./ (Ks+ appFs) -  xdata8s(js, 1));
appFSOLVEs(1, js)=fzero(funcs, [0 Ps(js)], optimset('fzero'));
end 
 

%% 
app=appFSOLVE';
apps=appFSOLVEs';
 
%% solve for secretases (see Equations~\ref{MonoDimerConservedEqn2})
% without SORLA
alpha=(- app.*  p(4) -   p(8).*  p(4) +  sqrt((- app.*  p(4) -   p(8).*  p(4)).^2 -  4.*   p(1).*   p(8).*   p(4).*  (- 2.*  app.^2.*  Ka.*  Kc.*   p(8) -  2.*  Kc.*   p(8).*   p(4))))./ (4.*  (app.^2 .* Ka.*  Kc.*   p(8) +  Kc.*   p(8).*   p(4)));
beta =(- app.*  p(6) -   p(10).*  p(6) +  sqrt((- app.*  p(6) -   p(10).*  p(6)).^2 -  4.*   p(2).*   p(10).*   p(6).*  (- 2.*  app.^2.*  Ka.*  Kb.*   p(10) -  2.*  Kb.*   p(10).*   p(6))))./ (4.*  (app.^2 .* Ka.*  Kb.*   p(10) +  Kb.*   p(10).*   p(6)));
%without SORLA
alphas=(-  apps.*  Kmad -   Kma.*  Kmad +  sqrt((-  apps.*  Kmad -   Kma.*  Kmad).^2 -  4.*   Atot.*   Kma.*   Kmad.*  (- 2.*   apps.^2.*  Ka.*  Kc.*   Kma -  2.*  Kc.*   Kma.*   Kmad)))./ (4.*  ( apps.^2 .* Ka.*  Kc.*   Kma +  Kc.*   Kma.*   Kmad));
betas =(-  apps.*  Kmbd -   Kmb.*  Kmbd +  sqrt((-  apps.*  Kmbd -   Kmb.*  Kmbd).^2 -  4.*   Btot.*   Kmb.*   Kmbd.*  (- 2.*   apps.^2.*  Ka.*  Kb.*   Kmb -  2.*  Kb.*   Kmb.*   Kmbd)))./ (4.*  ( apps.^2 .* Ka.*  Kb.*   Kmb +  Kb.*   Kmb.*   Kmbd));
 
% amount of free APP in monomer and dimer processing
app=appFSOLVE';
apps=appFSOLVEs';
appMon=app;
appDim=Ka.* (app.^2);
appMons=apps;
appDims=Ka.* (apps.^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% fitting to the experimental data
% without SORLA for dimer processing
fit11 =2.* (appDim) .*  Kc.* (alpha.^2).* p(3)./ p(4);% sAPPa
fit21= 2.* (appDim) .*  Kb.* (beta.^2).* p(5)./ p(6);% sAPPb
% without SORLA for monomer processing
fit12 = appMon .*  alpha.* p(7)./ p(8);% sAPPa
fit22= appMon .*  beta.* p(9)./ p(10);% sAPPb
% sum of  products w/o SORLA in monomer and dimer
fit1 = (fit11+ fit12); % sAPPa
fit2 = (fit21+ fit22); % sAPPb
 
% with SORLA for dimer processing
fit11s =2.* (appDims) .*  Kc.* (alphas.^2).* p(3)./ Kmad;% sAPPa
fit21s= 2.* (appDims) .*  Kb.* (betas.^2).* p(5)./ Kmbd;% sAPPb
% with SORLA for monomer processing
fit12s = appMons .*  alphas.* p(7)./ Kma;% sAPPa
fit22s = appMons .*  betas.* p(9)./ Kmb;% sAPPb
% sum of  products w/ SORLA in monomer and dimer
fit1s = (fit11s+ fit12s); % sAPPa
fit2s = (fit21s+ fit22s); % sAPPb

% RECALL: w and ws denote the number of experimental data without and with SORLA,  respectively
err11 = (fit1 -  data(:, 2))./ sqrt((sum(data(:, 2))./ w));
err22 = (fit2 -  data(:, 3))./ sqrt((sum(data(:, 3))./ w));
err11s = (fit1s -  datas(:, 2)) ./ sqrt((sum(datas(:, 2))./ ws));
err22s = (fit2s -  datas(:, 3)) ./ sqrt((sum(datas(:, 3))./ ws));
% error vector
err=vertcat(err11,  err22,  err11s, err22s);
end 
end